@@ -32,8 +32,6 @@ then
     touch ~/.config/budgie-desktop/keycontrol6
 fi
 
-bash -c 'sleep 5 && /usr/share/budgie-desktop/gdmcheck/gdmcheck.sh' &
-
 if [ -f ~/.config/budgie-desktop/firstrun ]
 then
     return 0
@@ -51,13 +49,6 @@ then
     cp -r /usr/share/budgie-desktop/home-folder/.config ~/
 fi
 
-# gnome-software
-GS=`which gnome-software`
-if [ "$GS" ]
-then
-    cp /usr/share/budgie-desktop/gnome-software-service.desktop ~/.config/autostart
-fi
-
 # templates
 bash -c 'sleep 20 && /usr/share/budgie-desktop/home-folder/copytemplates' &
 
